//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yaku](index.md)/[menzenOnly](menzen-only.md)

# menzenOnly

[common]\
val [menzenOnly](menzen-only.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否为门清限定
